"""Add project URL column to Python metadata

Revision ID: ff18da87f7c1
Revises: 295358ee27b1
Create Date: 2019-10-22 10:34:43.377908+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'ff18da87f7c1'
down_revision = '295358ee27b1'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('python_package_metadata', sa.Column('project_url', sa.String(length=256), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('python_package_metadata', 'project_url')
    # ### end Alembic commands ###
